@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Corentin Chary <corentin.chary@gmail.com>
+ * Copyright (C) 2010-2011 Corentin Chary <corentin.chary@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,6 +45,10 @@ Q_IMPORT_PLUGIN(stationsloweraustria);
 Q_IMPORT_PLUGIN(stationslatvia);
 Q_IMPORT_PLUGIN(stationsnewzealand);
 Q_IMPORT_PLUGIN(stationsusa);
+Q_IMPORT_PLUGIN(stationsaustralia);
+
+Q_IMPORT_PLUGIN(qtgeoservices_google);
+Q_IMPORT_PLUGIN(qtgeoservices_osm);
 #endif
 
 int main(int argc, char *argv[])
@@ -66,6 +70,7 @@ int main(int argc, char *argv[])
     Q_INIT_RESOURCE(latvia);
     Q_INIT_RESOURCE(new_zealand);
     Q_INIT_RESOURCE(usa);
+    Q_INIT_RESOURCE(australia);
 #endif
 
     QTranslator qtTranslator;
@@ -77,13 +82,17 @@ int main(int argc, char *argv[])
     lugdulovTranslator.load("lugdulov_" + QLocale::system().name(), ":/");
     app.installTranslator(&lugdulovTranslator);
 
+#if defined(LUGDULOV_MEEGO)
+    QCoreApplication::setOrganizationName("net.iksaif.lugdulov");
+#else
     QCoreApplication::setOrganizationName("Lugdulov");
+#endif
     QCoreApplication::setApplicationName("Lugdulov");
     QCoreApplication::setApplicationVersion(LUGDULOV_VERSION);
 
-#if defined(Q_OS_MAC) || defined(Q_OS_WINDOWS)
+#if defined(Q_OS_MAC) || defined(Q_OS_WINDOWS) || defined(Q_WS_MAEMO5) || defined(LUGDULOV_MEEGO)
     QDir dir(QApplication::applicationDirPath());
-#if defined(Q_OS_MAC)
+#if defined(Q_OS_MAC) || defined(Q_WS_MAEMO5) || defined(LUGDULOV_MEEGO)
     dir.cdUp();
 #endif
     dir.cd("plugins");
@@ -94,7 +103,7 @@ int main(int argc, char *argv[])
 
     MainWindow w;
 
-#ifdef Q_WS_S60
+#ifdef Q_OS_SYMBIAN
     w.showMaximized();
 #else
     w.show();
