@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Corentin Chary <corentin.chary@gmail.com>
+ * Copyright (C) 2010-2011 Corentin Chary <corentin.chary@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,10 +46,16 @@ MainWindow::MainWindow(QWidget *parent)
     ui(new Ui_MainWindow)
 {
   ui->setupUi(this);
-
+  manager = NULL;
 #ifdef HAVE_QT_LOCATION
   localisation = NULL;
 #endif
+#if defined(Q_WS_S60)
+  menuBar()->clear();
+  menuBar()->addAction(ui->settingsAction);
+  menuBar()->addAction(ui->aboutAction);
+  menuBar()->addAction(ui->aboutQtAction);
+#endif
 #if defined(Q_WS_MAEMO_5)
   ui->menu_File->removeAction(ui->quitAction);
   ui->menu_Help->removeAction(ui->aboutQtAction);
@@ -76,6 +82,9 @@ MainWindow::MainWindow(QWidget *parent)
   ui->titleLabel->hide();
 #endif
 
+#if defined(LUGDULOV_LITE)
+  setWindowTitle("Lugdulo'V Lite");
+#endif
 
 #if defined(LUGDULOV_FULL_UI)
   connect(ui->mapWidget, SIGNAL(centerChanged(const QPointF &)),
@@ -109,15 +118,6 @@ MainWindow::~MainWindow()
 void
 MainWindow::createButton()
 {
-  Settings conf;
-  QString selected = conf.value("StationsPlugin").toString();
-  StationsPlugin *selectedPlugin = NULL;
-
-  manager = new StationsPluginManager(this);
-
-  selectedPlugin = manager->station(selected);
-
-  setStationsPlugin(selectedPlugin);
   connect(ui->pushButton, SIGNAL(clicked(bool)), this, SLOT(buttonClicked()));
 }
 
@@ -146,6 +146,16 @@ MainWindow::createActions()
 void
 MainWindow::delayedInit()
 {
+  Settings conf;
+  QString selected = conf.value("StationsPlugin").toString();
+  StationsPlugin *selectedPlugin = NULL;
+
+  manager = new StationsPluginManager(this);
+
+  selectedPlugin = manager->station(selected);
+
+  setStationsPlugin(selectedPlugin);
+
 #if defined(HAVE_QT_BEARER) || QT_VERSION >= 0x040700
   QNetworkConfigurationManager manager;
   const bool selectIap = (manager.capabilities()& QNetworkConfigurationManager::CanStartAndStopInterfaces);
@@ -153,12 +163,10 @@ MainWindow::delayedInit()
   QNetworkSession* session = new QNetworkSession(ap, this);
 
   (void) selectIap;
-
   session->open();
+  qDebug() << "Network session" << session->isOpen();
 #endif
 #ifdef HAVE_QT_LOCATION
-  Settings conf;
-
   localisation = QGeoPositionInfoSource::createDefaultSource(this);
 
   if (!localisation) {
@@ -190,7 +198,12 @@ MainWindow::delayedInit()
 void
 MainWindow::positionRequestTimeout()
 {
+  qDebug() << "positionRequestTimeout";
 
+#if defined(LUGDULOV_FULL_UI)
+  if (!plugin)
+    buttonClicked();
+#endif
 }
 
 void
@@ -198,6 +211,8 @@ MainWindow::positionUpdated(QGeoPositionInfo info)
 {
   QGeoCoordinate coord = info.coordinate();
 
+  qDebug() << "Position Updated" << coord;
+
   if (!coord.isValid() || (coord.latitude() == 0 && coord.longitude() == 0))
     return ;
 
@@ -225,12 +240,22 @@ MainWindow::positionUpdated(QGeoPositionInfo info)
 void
 MainWindow::buttonClicked()
 {
-  PluginsDialog dlg(manager, this);
+  bool have_localization = false;
+
+#ifdef HAVE_QT_LOCATION
+  have_localization = !!localisation;
+#endif
+
+  PluginsDialog dlg(manager, have_localization, this);
+
+  dlg.setCurrentPlugin(plugin);
+
+#if defined(Q_WS_S60) || defined(Q_WS_SIMULATOR)
+  dlg.showMaximized();
+#endif
 
   if (dlg.exec())
     setStationsPlugin(dlg.plugin(), true);
-  else
-    setStationsPlugin(NULL, true);
 }
 
 void
@@ -241,6 +266,16 @@ MainWindow::setStationsPlugin(StationsPlugin *sta, bool save)
 
   plugin = sta;
 
+#if defined(LUGDULOV_FULL_UI)
+  if (!plugin) {
+    ui->mapWidget->hide();
+    ui->listWidget->hide();
+  } else {
+    ui->mapWidget->show();
+    ui->listWidget->show();
+  }
+#endif
+
   if (plugin)
     plugin->setParent(this);
 
@@ -267,6 +302,10 @@ MainWindow::about()
 {
   AboutDialog dialog(this);
 
+#if defined(Q_WS_S60) || defined(Q_WS_SIMULATOR)
+  dialog.showMaximized();
+#endif
+
   dialog.exec();
 }
 
@@ -279,6 +318,7 @@ MainWindow::aboutQt()
 void
 MainWindow::statusMsg(const QString & msg, int timeout)
 {
+  qDebug() << "Message" << msg << timeout;
 #ifdef Q_WS_MAEMO_5
   if (!timeout)
     timeout = QMaemo5InformationBox::NoTimeout;
@@ -295,7 +335,7 @@ MainWindow::chooseStationsPlugin()
 		       tr("We can't guess your current location, "
 			  "please choose one in the list."));
 
-  buttonClicked();
+  QTimer::singleShot(0, this, SLOT(buttonClicked()));
 }
 
 void
@@ -333,9 +373,10 @@ MainWindow::updatePlugin(void)
     /* Don't fetch stations from network on slow links */
     if (type != QNetworkConfiguration::BearerEthernet &&
 	type != QNetworkConfiguration::BearerWLAN &&
-	type != QNetworkConfiguration::BearerWiMAX)
+	type != QNetworkConfiguration::BearerWiMAX) {
+	  qDebug() << "Network is slow, skipping fechOnline()";
       return ;
-    else
+    } else
       break ;
   }
 #endif
@@ -351,6 +392,10 @@ MainWindow::settings()
 
   SettingsDialog dialog(this);
 
+#if defined(Q_WS_S60) || defined(Q_WS_SIMULATOR)
+  dialog.showMaximized();
+#endif
+
   if (dialog.exec())
     dialog.saveSettings();
 
