@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Corentin Chary <corentin.chary@gmail.com>
+ * Copyright (C) 2010-2011 Corentin Chary <corentin.chary@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,19 +33,21 @@
 #  include <QGeoPositionInfoSource>
 #  include <QGeoCoordinate>
 #  include <QGeoPositionInfo>
-# ifndef USE_QMAPCONTROL
+# if !defined(USE_QMAPCONTROL) && !defined(LUGDULOV_LITE)
 #  include <QGraphicsGeoMap>
 #  include <QGeoMapPixmapObject>
 #  include <QGeoServiceProvider>
+#  include <QGeoBoundingBox>
 # endif
 # else
 #  include <QtLocation/QGeoPositionInfoSource>
 #  include <QtLocation/QGeoPositionInfo>
 #  include <QtLocation/QGeoPositionInfoSource>
-# ifndef USE_QMAPCONTROL
+# if !defined(USE_QMAPCONTROL) && !defined(LUGDULOV_LITE)
 #  include <QtLocation/QGraphicsGeoMap>
 #  include <QtLocation/QGeoMapPixmapObject>
 #  include <QtLocation/QGeoServiceProvider>
+#  include <QtLocation/QGeoBoundingBox>
 # endif
 # endif
 #endif
