@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Corentin Chary <corentin.chary@gmail.com>
+ * Copyright (C) 2010-2011 Corentin Chary <corentin.chary@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,4 +26,4 @@ StationsPluginFactoryLowerAustria::StationsPluginFactoryLowerAustria()
   init("lower-austria");
 }
 
-Q_EXPORT_PLUGIN2(stationslower-austria, StationsPluginFactoryLowerAustria)
+Q_EXPORT_PLUGIN2(stationsloweraustria, StationsPluginFactoryLowerAustria)
