@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Corentin Chary <corentin.chary@gmail.com>
+ * Copyright (C) 2010-2011 Corentin Chary <corentin.chary@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,12 +18,21 @@
 
 #include <QtCore/QtPlugin>
 
-
 #include "factory.h"
+#include "miami.h"
 
 StationsPluginFactoryUsa::StationsPluginFactoryUsa()
 {
   init("usa");
 }
 
+StationsPluginSimple *
+StationsPluginFactoryUsa::pluginForType(const QString & type)
+{
+  if (type == "DecoBikes")
+    return new StationsPluginMiami();
+  else
+    return StationsPluginFactorySimple::pluginForType(type);
+}
+
 Q_EXPORT_PLUGIN2(stationsusa, StationsPluginFactoryUsa)
