@@ -4,7 +4,7 @@
   cyclocity.py
 
   Copyright (C) 2010 Patrick Installé <PatrickInstalle@P-Installe.be>
-  Copyright (C) 2010 Corentin Chary <corentincj@iksaif.net>
+  Copyright (C) 2010-2011 Corentin Chary <corentincj@iksaif.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -257,7 +257,17 @@ class CycloCity(Provider):
             'server' :  'www.citycycle.com.au',
             'lat': -27.47538,
             'lng': 153.019466
-            }
+            },
+    {
+            'city_uid'    : 'ljubljana',
+            'country_uid' : 'si',
+            'country_Name' : 'Slovenia',
+            'city_Name'    : 'Ljubljana',
+            'bike_name'    : 'Bicike(lj)',
+            'server' :  'www.bicikelj.si',
+            'lat': 46.055556,
+            'lng': 14.508333
+            },
     ]
 
     cache = {}
